@@ -6,6 +6,8 @@ import os
 from lark import Lark
 from lark.exceptions import LarkError
 from sca2d.outerscope import OuterScope
+from sca2d.scadclasses import UseIncStatment
+from sca2d.utilities import locate_file
 
 class ScadParser():
     '''
@@ -39,7 +41,15 @@ class Analyser:
         self._parser = ScadParser()
         self._parsed_files = {}
 
-    def parse_file(self, filename):
+    def parse_file(self, file_reference):
+        if isinstance(file_reference, str):
+            filename = file_reference
+        elif isinstance(file_reference, UseIncStatment):
+            filename = locate_file(file_reference)
+        else:
+            raise TypeError('Analyser.parse_file cannot accept an input of type '
+                            f'{type(file_reference)}')
+
         print(f'parsing {filename}')
         try:
             with open(filename, 'r') as file_obj:
@@ -65,23 +75,36 @@ class Analyser:
         #set defaults before running
 
         scope = self.parse_file(filename)
+        if scope is None:
+            return False
         if output_tree:
             with open('output.sca2d', 'w') as file_obj:
                 file_obj.write(scope.tree.pretty())
-        included_files = scope.included_files
-        used_files = scope.used_files
-        for inc_file in included_files:
-            if inc_file.filename in self._parsed_files:
-                continue
-            inc_scope = self.parse_file(inc_file.filename)
-            extra_includes = inc_scope.included_files
-            for extra_include in extra_includes:
-                if extra_include not in [included_files, filename]:
-                    included_files.append(extra_include)
-        for used_file in used_files:
-            if used_file.filename not in self._parsed_files:
-                self.parse_file(used_file.filename)
+
+        self._parse_required_files(scope)
 
         scope.analyse_tree(self._parsed_files)
         scope.print_messages()
         return True
+
+    def _parse_required_files(self, scope):
+        self._parse_used_files(scope)
+        self._parse_included_files(scope)
+
+    def _parse_used_files(self, scope):
+        used_files = scope.used_files
+        for used_file in used_files:
+            if used_file.filename not in self._parsed_files:
+                self.parse_file(used_file)
+
+    def _parse_included_files(self, scope):
+        included_files = scope.included_files
+        for inc_file in included_files:
+            if inc_file.filename not in self._parsed_files:
+                inc_scope = self.parse_file(inc_file)
+                if inc_scope is None:
+                    continue
+                extra_includes = inc_scope.included_files
+                for extra_include in extra_includes:
+                    if extra_include not in [included_files, scope.filename]:
+                        included_files.append(extra_include)
